Creating an account
===================

1. Navigate to the *Terminus GPS Notifications* `register`_ page.

.. image:: ../images/register_page.png

2. Fill out the registration form.

.. image:: ../images/register_page_filled.png

3. Click the *Register* button at the bottom of the form.

.. image:: ../images/register_page_hover_button.png

4. You'll be redirected to the login page. `Login`_ using the credentials you used in step 3.

.. image:: ../images/login_page_filled.png

.. _register: https://api.terminusgps.com/register/
.. _login: https://api.terminusgps.com/login/
